default_runner_root_from

Function default_runner_root_from 

pub fn default_runner_root_from(
    source: PlatformDefault<'_>,
) -> Result<LocalAbsolutePath, RunnerRootError>
Resolves a platform default from an explicit source.

Errors

RunnerRootError::SystemDirectoryUnusable when the reported system directory is not an ordinary drive path; RunnerRootError::ApplicationRuntimeDirectoryUnusable or RunnerRootError::NonUnicode when the application runtime directory is not a storable local path.