pub const fn host_definition_kind(mode: StartMode) -> DefinitionKindExpand description
Which manager holds a given start-mode domain on the platform this binary was built for.
pub const fn host_definition_kind(mode: StartMode) -> DefinitionKindWhich manager holds a given start-mode domain on the platform this binary was built for.