pub fn decode_console_output(bytes: &[u8]) -> DecodedOutputExpand description
Decodes what a Windows console program wrote to a pipe.
pub fn decode_console_output(bytes: &[u8]) -> DecodedOutputDecodes what a Windows console program wrote to a pipe.